title:      Docnado
desc:       Rapid documentation tool to blow you away.
date:       2018/08/05
version:    1.0.0
template:   document
nav:        Home __-1__
percent:    100
authors:    enq@heinventions.com

Welcome to the user guide for docnado, the lightweight and easy to use documentation hosting tool.
{: .info}

Docnado makes it easy to start and maintain a Markdown documentation project. Store your own data your own way.

# Basic Features

Docnado renders an adapted Markdown to provide:

* Images, Video, YouTube links, CSV tables.
* Code highlighting.
* File download blocks.
* Lists and Tables.
* Document defined template selection.
* Document Meta-data.
* Auto-generated index sidebar.

Docnado can:

* Output documents as insecure HTML on a localhost.
* Output documents as PDF files via the HTML server.
* Create a **static** set of HTML files that contain the documentation and related resources.
* Automatically find broken reference links in the generated HTML
* Automatically find orphan files (i.e. images) that are not referenced by generated HTML

Check out the links to the left to see how to use docnado.
{: .tip}

# Why Docnado?
Docnado was born because we just wanted to write documentation with a decent out of the box style, a nav system, and support for videos.

Today docnado implements markdown plus videos, YouTube, PDFs, CSVs, code highlighting, file downloads, lists, tables, meta-data, custom templates, callouts.

You can store all your docs in version control, so you have complete control of your data.

Advanced tools allow you to check that all files referenced (i.e. images) have corresponding files on disk, and vice-versa, that all files in the docs are referenced in the text. You can also tie your documentation into continuious integration steps that make sure that any changes people make do not break any other documents and follow a consistent language and style guide.
